::: django_slack_tools.slack_messages.shortcuts
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.request
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.response
    options:
      show_root_heading: true
